========================
Neo 0.11.0 release notes
========================

1st September 2022

.. currentmodule:: neo.io

Bug fixes and improvements in IO modules
----------------------------------------

Bug fixes and/or improvements have been made to :class:`NWBIO`, :class:`NeoMatlabIO`, :class:`NixIO`,
:class:`AxonIO`, :class:`SpikeGLXIO`, :class:`NeuroshareIO`, :class:`NeuroScopeIO`,
:class:`NeuralynxIO`, :class:`OpenEphysIO`, :class:`AsciiSignalIO`, :class:`AlphaOmegaIO`,
and :class:`TdtIO`.

New IO modules
--------------

Modules :class:`BiocamIO` and :class:`EDFIO` have been added.

Supported NumPy versions
------------------------

We no longer support versions of NumPy older than 1.18.5.


Other changes
-------------

.. currentmodule:: neo.io.spiketrainlist

- documentation fixes and updates
- improvements to :class:`SpikeTrainList`

See all `pull requests`_ included in this release and the `list of closed issues`_.

Acknowledgements
----------------

Thanks to Julia Sprenger, Samuel Garcia, Heberto Mayorquin, Andrew Davison, Tom Donoghue,
Alessio Buccino, Thomas Perret, Saksham Sharda, Ben Dichter and Elodie Legouée
for their contributions to this release.

.. generated with git shortlog --since=2022-03-08 -sne then checking Github for PRs merged since the last release but with commits before then

.. _`list of closed issues`: https://github.com/NeuralEnsemble/python-neo/issues?q=is%3Aissue+milestone%3A0.11.0+is%3Aclosed
.. _`pull requests`: https://github.com/NeuralEnsemble/python-neo/pulls?q=is%3Apr+is%3Aclosed+merged%3A%3E2022-03-08+milestone%3A0.11.0
